@@ -19,8 +19,6 @@
 #include <QDebug>
 #include <QtWebEngine>
 
-static const char description[] =
-    I18N_NOOP("KDE Frontend to mathematical applications");
 
 int main(int argc, char **argv)
 {
@@ -30,6 +28,7 @@ int main(int argc, char **argv)
     QWebEngineUrlScheme::registerScheme(qthelp);
 
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     // Add our custom plugins path, where we install our plugins, if it isn't default path
@@ -70,7 +69,7 @@ int main(int argc, char **argv)
     KAboutData about(QLatin1String("cantor"),
                      QLatin1String("Cantor"),
                      QLatin1String(CANTOR_VERSION),
-                     i18n(description),
+                     i18n("KDE Frontend to mathematical applications"),
                      KAboutLicense::GPL,
                      i18n("(C) 2016 Filipe Saraiva<br/>(C) 2009-2015 Alexander Rieder"),
                      QString(),
